MyopicTorus

Struct MyopicTorus 

pub struct MyopicTorus<I: ICompatible<V>, V: VCompatible<I>>(pub Torus<I, V>);
A deliberately overlapping bounded domain on Torus.

This exercises NerveComplex when many cover nodes see the same region rather than forming the regular cover represented by TorusCover.

Tuple Fields

0: Torus<I, V>

Implementations

Source

impl<I: ICompatible<V>, V: VCompatible<I>> MyopicTorus<I, V>

pub fn s() -> usize

Returns the number of cover samples along each torus coordinate.