VCompatible

Trait VCompatible 

pub trait VCompatible<I: Euclidean<F: Real + From<Self::F>> + From<[I::F; 1]> + From<[Self::F; 1]>>:
    Euclidean<F: Real + Send + Sync>
    + From<[I::F; 2]>
    + 'static
    + Send
    + Sync { }
Dimensional-compatibility bound for the ambient type of a KleinBottle/Torus, relating it to the inner circle type I.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I: Euclidean<F: Real + From<V::F>> + From<[I::F; 1]> + From<[V::F; 1]> + 'static + Send + Sync, V: Euclidean<F: Real + Send + Sync> + From<[I::F; 2]> + 'static + Send + Sync> VCompatible<I> for V