ArrowCategory

Type Alias ArrowCategory 

pub type ArrowCategory<C: Category + 'static, D: Ob<C>, E: Ob<C>> = ๐’ฏ<ห<BindsTyping<C, D, <D as Ob<C>>::Context, E, <E as Ob<C>>::Context>, ร˜>, ร˜>;
Construct the concrete context of an arrow D -> E in C.

Both endpoints are bound by one structural association, so a domain cannot exist without its codomain.

Aliased Type

pub struct ArrowCategory<C: Category + 'static, D: Ob<C>, E: Ob<C>>(/* private fields */);